@@ -19,6 +19,7 @@ import (
 	"bytes"
 	"context"
 	"crypto/tls"
+	"crypto/x509"
 	"errors"
 	"fmt"
 	"io"
@@ -439,10 +440,22 @@ func NewStdClient(o *HTTPOptions) (*Client, error) {
 		if len(o.Cert) > 0 && len(o.Key) > 0 {
 			cert, err := tls.LoadX509KeyPair(o.Cert, o.Key)
 			if err != nil {
-				log.Errf(fmt.Sprintf("%v", err))
-			} else {
-				tr.TLSClientConfig.Certificates = []tls.Certificate{cert}
+				log.Errf("LoadX509KeyPair error for cert %v / key %v: %v", o.Cert, o.Key, err)
+				return nil, err
 			}
+			tr.TLSClientConfig.Certificates = []tls.Certificate{cert}
+		}
+		if len(o.CACert) > 0 {
+			// Load CA cert
+			caCert, err := ioutil.ReadFile(o.CACert)
+			if err != nil {
+				log.Errf("Unable to read CA from %v: %v", o.CACert, err)
+				return nil, err
+			}
+			log.LogVf("Using custom CA from %v", o.CACert)
+			caCertPool := x509.NewCertPool()
+			caCertPool.AppendCertsFromPEM(caCert)
+			tr.TLSClientConfig.RootCAs = caCertPool
 		}
 	}
 
